//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Description of knot strokes and sections.
//
//		Traditionally, Celtic knotwork is drawn on a diagonal grid
//		overlaid with straight lines and circles.  Samhain uses
//		a simpler method devised by Andy Sloss, which divides the knot
//		into sections at every other grid point.  Each section can be
//		uniquely described by the directions in which the knot passes
//		through the section's corners, plus the directions the two lines
//		take in the interior of the section.
//		There are three possible directions (diagonal, horizontal and
//		vertical), so there are 3^5 = 243 basic sections.  The horizontal
//		and vertical sections can be split in half for closing up the edges
//		of a knot, yielding another 36 shapes.  These are represented
//		as a section with two corners that have "no" direction.
//
//		Because of symmetries, the 279 different sections can be drawn
//		using only 10 basic strokes.  See KnotSectionCache.cpp for the
//		actual implementation.
//
//		It would probably be possible to further simplify drawing by splitting
//		each section into quarters.

#ifndef KNOTSECTION_H
#define KNOTSECTION_H

enum direction {		// Directions of strokes and sections.
	D = 0,				// diagonal
	H = 1,				// horizontal
	V = 2,				// vertical
	N = 3					// none (edge sections only)
};

class KnotSection {
	const direction mType, mLT, mRT, mLB, mRB;

public:
	KnotSection(
		direction type,
		direction lt, direction rt, direction lb, direction rb)
	:	mType(type), mLT(lt), mRT(rt), mLB(lb), mRB(rb)
	{
		// empty
	}
	
	direction Type(void) const				{ return mType; }
	direction LeftTop(void) const			{ return mLT; }
	direction RightTop(void) const		{ return mRT; }
	direction LeftBottom(void) const		{ return mLB; }
	direction RightBottom(void) const	{ return mRB; }
};

#endif
