//		Copyright © 1997–2000  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The application class.

#include <Alert.h>
#include <Application.h>
#include <Directory.h>
#include <Entry.h>
#include <GraphicsDefs.h>
#include <Point.h>
#include <Rect.h>
#include <Roster.h>
#include <TextView.h>
#include <View.h>
#include <Window.h>

#include "SamhainApp.h"
#include "SamhainView.h"
#include "SamhainWindow.h"

#define SAVER_DIRECTORY "/boot/home/config/add-ons/Screen Savers"

SamhainApplication::SamhainApplication(void)
:	inherited("application/x-vnd.jjk-samhain")
{
	// empty
}

SamhainApplication::~SamhainApplication(void)
{
	// empty
}

void
SamhainApplication::ReadyToRun(void)
{
	// Create the views.
	const BRect knotFrame(0, 0, 350, 100);
	BView *pKnotView = new SamhainView(knotFrame);
	
	const BRect textFrame(100, 0, 350, 50);
	const BRect textRect(5, 5, 240, 45);
	BTextView *pText =
		new BTextView(textFrame, "Samhain", textRect, B_FOLLOW_ALL, B_WILL_DRAW);
	pText->SetViewColor(100, 255, 100);
	BFont font(be_plain_font);
	font.SetSize(10.0);
	pText->SetFontAndColor(&font);
	pText->SetText(
		"Samhain is an add-on module for the BeOS screen saver. "
		"Click “Install” to move it into the folder “" SAVER_DIRECTORY "”.");
	pText->MakeEditable(FALSE);
	pText->MakeSelectable(FALSE);
	pText->SetWordWrap(TRUE);	
	pKnotView->AddChild(pText);

	// Create the window, wait for selection.
	const char *const buttonLabels[] = { "Cancel", "Install" };
	const int32 selection = (new SamhainWindow(pKnotView, buttonLabels))->Go();
	if (selection == 1) {
		// "Install" selected.  Try to move executable.
		bool success = false;
		app_info info;
		if (GetAppInfo(&info) == B_NO_ERROR) {
			BEntry appEntry(&(info.ref));
			if (appEntry.InitCheck() == B_NO_ERROR) {
				BDirectory saverDir(SAVER_DIRECTORY);
				if (saverDir.InitCheck() == B_NO_ERROR) {
					if (appEntry.MoveTo(&saverDir, NULL, true) == B_NO_ERROR) {
						success = true;
					}
				}
			}
		}
		
		if (!success) {
			(new BAlert("",
							"Installation in “" SAVER_DIRECTORY "” failed.  "
							"Try using Tracker instead.",
							"Sorry"))->Go();
		}

		// Nothing more to do.
		PostMessage(B_QUIT_REQUESTED);

	} else {
		// Action canceled.
		PostMessage(B_QUIT_REQUESTED);
	}
}
